@@ -31,9 +31,9 @@ const DragState = {
 };
 
 const DRAG_CURSOR_MAP = {
-    0: Meta.Cursor.DND_UNSUPPORTED_TARGET,
-    1: Meta.Cursor.DND_COPY,
-    2: Meta.Cursor.DND_MOVE,
+    0: Meta.Cursor.NO_DROP,
+    1: Meta.Cursor.COPY,
+    2: Meta.Cursor.MOVE,
 };
 
 export const DragDropResult = {
@@ -365,7 +365,8 @@ class _Draggable extends Signals.EventEmitter {
                 device = event.get_device();
 
             if (device === undefined) {
-                let seat = Clutter.get_default_backend().get_default_seat();
+                const backend = this.actor.get_context().get_backend();
+                const seat = backend.get_default_seat();
                 device = seat.get_pointer();
             }
         }
@@ -385,7 +386,7 @@ class _Draggable extends Signals.EventEmitter {
             this._ungrabActor();
 
         this._grabEvents(device, sequence);
-        global.display.set_cursor(Meta.Cursor.DND_IN_DRAG);
+        global.display.set_cursor(Meta.Cursor.NO_DROP);
 
         this._dragX = this._dragStartX = stageX;
         this._dragY = this._dragStartY = stageY;
@@ -627,7 +628,7 @@ class _Draggable extends Signals.EventEmitter {
             }
             target = target.get_parent();
         }
-        global.display.set_cursor(Meta.Cursor.DND_IN_DRAG);
+        global.display.set_cursor(Meta.Cursor.NO_DROP);
         return GLib.SOURCE_REMOVE;
     }
 
