@@ -36,7 +36,8 @@ export const Slider = GObject.registerClass({
         super.vfunc_style_changed();
 
         const themeNode = this.get_theme_node();
-        this._handleRadius = themeNode.get_length('-slider-handle-radius');
+        this._handleRadius =
+            Math.round(2 * themeNode.get_length('-slider-handle-radius')) / 2;
     }
 
     vfunc_repaint() {
@@ -48,18 +49,17 @@ export const Slider = GObject.registerClass({
         let [width, height] = this.get_surface_size();
         const rtl = this.get_text_direction() === Clutter.TextDirection.RTL;
 
-        const ceiledHandleRadius = Math.ceil(this._handleRadius);
         const handleY = height / 2;
 
-        let handleX = ceiledHandleRadius +
-            (width - 2 * ceiledHandleRadius) * this._value / this._maxValue;
+        let handleX = this._handleRadius +
+            (width - 2 * this._handleRadius) * this._value / this._maxValue;
         if (rtl)
             handleX = width - handleX;
 
         let color = themeNode.get_foreground_color();
         cr.setSourceColor(color);
         cr.arc(handleX, handleY, this._handleRadius, 0, 2 * Math.PI);
-        cr.fillPreserve();
+        cr.fill();
         cr.$dispose();
     }
 
