@@ -1,9 +1,6 @@
 /* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*- */
-#ifndef __SHELL_APP_SYSTEM_PRIVATE_H__
-#define __SHELL_APP_SYSTEM_PRIVATE_H__
+#pragma once
 
 #include "shell-app-system.h"
 
 void _shell_app_system_notify_app_state_changed (ShellAppSystem *self, ShellApp *app);
-
-#endif
