@@ -44,9 +44,7 @@
 #include "shell-window-tracker.h"
 #include "shell-app-usage.h"
 #include "shell-app-cache-private.h"
-#include "shell-wm.h"
 #include "shell-util.h"
-#include "st.h"
 #include "switcheroo-control.h"
 
 static ShellGlobal *the_object = NULL;
@@ -114,7 +112,6 @@ enum {
   PROP_WINDOW_MANAGER,
   PROP_SETTINGS,
   PROP_DATADIR,
-  PROP_IMAGEDIR,
   PROP_USERDATADIR,
   PROP_FOCUS_MANAGER,
   PROP_FRAME_TIMESTAMPS,
@@ -227,29 +224,13 @@ shell_global_set_property(GObject         *object,
       global->session_mode = g_ascii_strdown (g_value_get_string (value), -1);
       break;
     case PROP_FRAME_TIMESTAMPS:
-      {
-        gboolean enable = g_value_get_boolean (value);
-
-        if (global->frame_timestamps != enable)
-          {
-            global->frame_timestamps = enable;
-            g_object_notify_by_pspec (object, props[PROP_FRAME_TIMESTAMPS]);
-          }
-      }
+      shell_global_set_frame_timestamps (global, g_value_get_boolean (value));
       break;
     case PROP_FRAME_FINISH_TIMESTAMP:
-      {
-        gboolean enable = g_value_get_boolean (value);
-
-        if (global->frame_finish_timestamp != enable)
-          {
-            global->frame_finish_timestamp = enable;
-            g_object_notify_by_pspec (object, props[PROP_FRAME_FINISH_TIMESTAMP]);
-          }
-      }
+      shell_global_set_frame_finish_timestamp (global, g_value_get_boolean (value));
       break;
     case PROP_FORCE_ANIMATIONS:
-      global->force_animations = g_value_get_boolean (value);
+      shell_global_set_force_animations (global, g_value_get_boolean (value));
       break;
     case PROP_AUTOMATION_SCRIPT:
       g_set_object (&global->automation_script, g_value_get_object (value));
@@ -289,29 +270,20 @@ shell_global_get_property(GObject         *object,
       g_value_set_object (value, global->workspace_manager);
       break;
     case PROP_SCREEN_WIDTH:
-      {
-        int width, height;
-
-        meta_display_get_size (global->meta_display, &width, &height);
-        g_value_set_int (value, width);
-      }
+      g_value_set_int (value, shell_global_get_screen_width (global));
+      break;
       break;
     case PROP_SCREEN_HEIGHT:
-      {
-        int width, height;
-
-        meta_display_get_size (global->meta_display, &width, &height);
-        g_value_set_int (value, height);
-      }
+      g_value_set_int (value, shell_global_get_screen_height (global));
       break;
     case PROP_STAGE:
       g_value_set_object (value, global->stage);
       break;
     case PROP_WINDOW_GROUP:
-      g_value_set_object (value, meta_get_window_group_for_display (global->meta_display));
+      g_value_set_object (value, meta_compositor_get_window_group (global->compositor));
       break;
     case PROP_TOP_WINDOW_GROUP:
-      g_value_set_object (value, meta_get_top_window_group_for_display (global->meta_display));
+      g_value_set_object (value, meta_compositor_get_top_window_group (global->compositor));
       break;
     case PROP_WINDOW_MANAGER:
       g_value_set_object (value, global->wm);
@@ -322,9 +294,6 @@ shell_global_get_property(GObject         *object,
     case PROP_DATADIR:
       g_value_set_string (value, global->datadir);
       break;
-    case PROP_IMAGEDIR:
-      g_value_set_string (value, global->imagedir);
-      break;
     case PROP_USERDATADIR:
       g_value_set_string (value, global->userdatadir);
       break;
@@ -591,7 +560,7 @@ shell_global_class_init (ShellGlobalClass *klass)
 
   props[PROP_STAGE] =
     g_param_spec_object ("stage", NULL, NULL,
-                         CLUTTER_TYPE_ACTOR,
+                         CLUTTER_TYPE_STAGE,
                          G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
 
   props[PROP_WINDOW_GROUP] =
@@ -619,11 +588,6 @@ shell_global_class_init (ShellGlobalClass *klass)
                          NULL,
                          G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
 
-  props[PROP_IMAGEDIR] =
-    g_param_spec_string ("imagedir", NULL, NULL,
-                         NULL,
-                         G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
-
   props[PROP_USERDATADIR] =
     g_param_spec_string ("userdatadir", NULL, NULL,
                          NULL,
@@ -652,7 +616,7 @@ shell_global_class_init (ShellGlobalClass *klass)
   props[PROP_FORCE_ANIMATIONS] =
     g_param_spec_boolean ("force-animations", NULL, NULL,
                           FALSE,
-                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
+                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   props[PROP_AUTOMATION_SCRIPT] =
     g_param_spec_object ("automation-script", NULL, NULL,
@@ -765,6 +729,28 @@ shell_global_set_stage_input_region (ShellGlobal *global,
 #endif
 }
 
+/**
+ * shell_global_get_backend:
+ *
+ * Return value: (transfer none): The #MetaBackend
+ */
+MetaBackend *
+shell_global_get_backend (ShellGlobal *global)
+{
+  return global->backend;
+}
+
+/**
+ * shell_global_get_compositor:
+ *
+ * Return value: (transfer none): The #MetaCompositor
+ */
+MetaCompositor *
+shell_global_get_compositor (ShellGlobal *global)
+{
+  return global->compositor;
+}
+
 /**
  * shell_global_get_context:
  *
@@ -809,6 +795,28 @@ shell_global_get_workspace_manager (ShellGlobal  *global)
   return global->workspace_manager;
 }
 
+/**
+ * shell_global_get_window_manager:
+ *
+ * Return value: (transfer none): The default #ShellWM
+ */
+ShellWM *
+shell_global_get_window_manager (ShellGlobal  *global)
+{
+  return global->wm;
+}
+
+/**
+ * shell_global_get_focus_manager:
+ *
+ * Return value: (transfer none): The default #StFocusManager
+ */
+StFocusManager *
+shell_global_get_focus_manager (ShellGlobal  *global)
+{
+  return global->focus_manager;
+}
+
 /**
  * shell_global_get_window_actors:
  *
@@ -824,13 +832,53 @@ shell_global_get_window_actors (ShellGlobal *global)
 
   g_return_val_if_fail (SHELL_IS_GLOBAL (global), NULL);
 
-  for (l = meta_get_window_actors (global->meta_display); l; l = l->next)
+  for (l = meta_compositor_get_window_actors (global->compositor); l; l = l->next)
     if (!meta_window_actor_is_destroyed (l->data))
       filtered = g_list_prepend (filtered, l->data);
 
   return g_list_reverse (filtered);
 }
 
+/**
+ * shell_global_get_window_group:
+ *
+ * Return value: (transfer none):
+ */
+ClutterActor *
+shell_global_get_window_group (ShellGlobal *global)
+{
+  return meta_compositor_get_window_group (global->compositor);
+}
+
+/**
+ * shell_global_get_top_window_group:
+ *
+ * Return value: (transfer none):
+ */
+ClutterActor *
+shell_global_get_top_window_group (ShellGlobal *global)
+{
+  return meta_compositor_get_top_window_group (global->compositor);
+}
+
+int
+shell_global_get_screen_width (ShellGlobal *global)
+{
+  int width;
+
+  meta_display_get_size (global->meta_display, &width, NULL);
+  return width;
+}
+
+int
+shell_global_get_screen_height (ShellGlobal *global)
+{
+  int height;
+
+  meta_display_get_size (global->meta_display, NULL, &height);
+  return height;
+}
+
 static void
 global_stage_notify_width (GObject    *gobject,
                            GParamSpec *pspec,
@@ -959,7 +1007,7 @@ entry_cursor_func (StEntry  *entry,
   ShellGlobal *global = user_data;
 
   meta_display_set_cursor (global->meta_display,
-                           use_ibeam ? META_CURSOR_IBEAM : META_CURSOR_DEFAULT);
+                           use_ibeam ? META_CURSOR_TEXT : META_CURSOR_DEFAULT);
 }
 
 #ifdef HAVE_X11
@@ -998,7 +1046,7 @@ _shell_global_set_plugin (ShellGlobal *global,
   global->backend = meta_context_get_backend (context);
   global->workspace_manager = meta_display_get_workspace_manager (display);
 
-  global->stage = CLUTTER_STAGE (meta_get_stage_for_display (display));
+  global->stage = CLUTTER_STAGE (meta_backend_get_stage (global->backend));
 
   st_entry_set_cursor_func (entry_cursor_func, global);
   st_clipboard_set_selection (meta_display_get_selection (display));
@@ -1008,16 +1056,16 @@ _shell_global_set_plugin (ShellGlobal *global,
   g_signal_connect (global->stage, "notify::height",
                     G_CALLBACK (global_stage_notify_height), global);
 
-  clutter_threads_add_repaint_func_full (CLUTTER_REPAINT_FLAGS_PRE_PAINT,
-                                         global_stage_before_paint,
-                                         global, NULL);
+  clutter_threads_add_repaint_func (CLUTTER_REPAINT_FLAGS_PRE_PAINT,
+                                    global_stage_before_paint,
+                                    global, NULL);
 
   g_signal_connect (global->stage, "after-paint",
                     G_CALLBACK (global_stage_after_paint), global);
 
-  clutter_threads_add_repaint_func_full (CLUTTER_REPAINT_FLAGS_POST_PAINT,
-                                         global_stage_after_swap,
-                                         global, NULL);
+  clutter_threads_add_repaint_func (CLUTTER_REPAINT_FLAGS_POST_PAINT,
+                                    global_stage_after_swap,
+                                    global, NULL);
 
   shell_perf_log_define_event (shell_perf_log_get_default(),
                                "clutter.stagePaintStart",
@@ -1286,7 +1334,7 @@ shell_global_get_pointer (ShellGlobal         *global,
   MetaCursorTracker *tracker;
   graphene_point_t point;
 
-  tracker = meta_cursor_tracker_get_for_display (global->meta_display);
+  tracker = meta_backend_get_cursor_tracker (global->backend);
   meta_cursor_tracker_get_pointer (tracker, &point, &raw_mods);
 
   if (x)
@@ -1576,6 +1624,46 @@ shell_global_get_session_mode (ShellGlobal *global)
   return global->session_mode;
 }
 
+gboolean
+shell_global_get_force_animations (ShellGlobal *global)
+{
+  return global->force_animations;
+}
+
+void
+shell_global_set_force_animations (ShellGlobal *global,
+                                   gboolean     force)
+{
+  if (force == global->force_animations)
+    return;
+
+  global->force_animations = force;
+  g_object_notify_by_pspec (G_OBJECT (global), props[PROP_FORCE_ANIMATIONS]);
+}
+
+const char *
+shell_global_get_datadir (ShellGlobal *global)
+{
+  return global->datadir;
+}
+
+const char *
+shell_global_get_userdatadir (ShellGlobal *global)
+{
+  return global->userdatadir;
+}
+
+/**
+ * shell_global_get_automation_script:
+ *
+ * Return value: (transfer none):
+ */
+GFile *
+shell_global_get_automation_script (ShellGlobal *global)
+{
+  return global->automation_script;
+}
+
 static void
 delete_variant_cb (GObject      *object,
                    GAsyncResult *result,
@@ -1886,3 +1974,37 @@ shell_global_get_app_usage (ShellGlobal *global)
     global->app_usage = g_object_new (SHELL_TYPE_APP_USAGE, NULL);
   return global->app_usage;
 }
+
+gboolean
+shell_global_get_frame_timestamps (ShellGlobal *global)
+{
+  return global->frame_timestamps;
+}
+
+void
+shell_global_set_frame_timestamps (ShellGlobal *global,
+                                   gboolean     enable)
+{
+  if (global->frame_timestamps != enable)
+    {
+      global->frame_timestamps = enable;
+      g_object_notify_by_pspec (G_OBJECT (global), props[PROP_FRAME_TIMESTAMPS]);
+    }
+}
+
+gboolean
+shell_global_get_frame_finish_timestamp (ShellGlobal *global)
+{
+  return global->frame_finish_timestamp;
+}
+
+void
+shell_global_set_frame_finish_timestamp (ShellGlobal *global,
+                                         gboolean     enable)
+{
+  if (global->frame_finish_timestamp != enable)
+    {
+      global->frame_finish_timestamp = enable;
+      g_object_notify_by_pspec (G_OBJECT (global), props[PROP_FRAME_FINISH_TIMESTAMP]);
+    }
+}
