@@ -174,12 +174,15 @@ st_viewport_scrollable_interface_init (StScrollableInterface *iface)
   iface->get_adjustments = scrollable_get_adjustments;
 }
 
-static void
+void
 st_viewport_set_clip_to_view (StViewport *viewport,
                               gboolean    clip_to_view)
 {
-  StViewportPrivate *priv =
-    st_viewport_get_instance_private (viewport);
+  StViewportPrivate *priv;
+
+  g_return_if_fail (ST_IS_VIEWPORT (viewport));
+
+  priv = st_viewport_get_instance_private (viewport);
 
   if (!!priv->clip_to_view != !!clip_to_view)
     {
@@ -189,6 +192,17 @@ st_viewport_set_clip_to_view (StViewport *viewport,
     }
 }
 
+gboolean
+st_viewport_get_clip_to_view (StViewport *viewport)
+{
+  StViewportPrivate *priv;
+
+  g_return_val_if_fail (ST_IS_VIEWPORT (viewport), FALSE);
+
+  priv = st_viewport_get_instance_private (viewport);
+  return priv->clip_to_view;
+}
+
 static void
 st_viewport_get_property (GObject    *object,
                           guint       property_id,
