@@ -35,6 +35,7 @@ struct _NaXembedClass
 
   void (* plug_added) (NaXembed *xembed);
   void (* plug_removed) (NaXembed *xembed);
+  void (* reconfigured) (NaXembed *xembed);
 };
 
 MetaX11Display * na_xembed_get_x11_display (NaXembed *xembed);
@@ -58,7 +59,11 @@ void na_xembed_get_size (NaXembed *xembed,
 			 int      *width,
 			 int      *height);
 
+void na_xembed_set_available_size (NaXembed *xembed,
+                                   int       width,
+                                   int       height);
+
 void na_xembed_set_background_color (NaXembed        *xembed,
                                      const CoglColor *color);
 
-G_END_DECLS
\ No newline at end of file
+G_END_DECLS
